@@ -1,5 +1,4 @@
 get.array.info <- function(data) {
-
   ## Array-specific information; maybe this could go in a file, rather
   ## than be read-in separately.  Useful for the HDF5 functions.
   
@@ -13,7 +12,7 @@ get.array.info <- function(data) {
     corr.breaks <-  c(0, seq(35, by=70, length=9))
   }
 
-  if (array == 'Axion_MW') {
+  if ( any(grep('^Axion', array))) {
     ## e.g. Neurotox ongoing project.
     xlim <- c(0, 8000)
     ylim <- c(0, 6000)
@@ -21,9 +20,8 @@ get.array.info <- function(data) {
     corr.breaks <-  0                   #TODO; by default, do no breaks!
   }
 
-
   layout <- list(xlim = xlim, ylim = ylim, spacing = spacing, 
-                 pos = pos)
+                 pos = pos, array=array)
   class(layout) <- "mealayout"
   list(layout=layout, corr.breaks=corr.breaks)
 }
