@@ -40,13 +40,8 @@ plot.mm.s <- function(s, whichcells=NULL,
   ## If FOR.FIGURE is true, we make a slightly different outline, which
   ## is useful for making the figures.
 
-  if (is.null(whichcells)) {
-    whichcells <- 1:s$NCells
-  }
+  whichcells = names.to.indexes(names(s$spikes), whichcells, allow.na=TRUE)
 
-  if (is.character(whichcells[1])) {
-    whichcells = names.to.indexes(names(s$spikes), whichcells, allow.na=TRUE)
-  }
 
   if (is.null(main)) {
     main <- basename(s$file)
